package it.polito.bigdata.spark.StreamingWordCount;

import org.apache.spark.streaming.Durations;
import org.apache.spark.streaming.api.java.JavaDStream;
import org.apache.spark.streaming.api.java.JavaPairDStream;
import org.apache.spark.streaming.api.java.JavaStreamingContext;

import org.apache.spark.SparkConf;

public class SparkDriver {

	public static void main(String[] args) {

		String outputPathPrefix;
		String inputFolder;

		inputFolder = args[0];
		outputPathPrefix = args[1];

		// Create a configuration object and set the name of the application
		SparkConf conf = new SparkConf().setAppName("Spark Streaming word count");

		// Create a Spark Streaming Context object
		JavaStreamingContext jssc = new JavaStreamingContext(conf, Durations.seconds(10));

		// Create a DStream reading the content of the input folder
		JavaDStream<String> lines = jssc.textFileStream(inputFolder);

		// Apply the "standard" trasformations to perform the word count task
		// However, the "returned" RDDs are DStream/PairDStream RDDs
		JavaDStream<String> words = lines.flatMap(new Split());

		JavaPairDStream<String, Integer> wordsOnes = words.mapToPair(new WordOne());

		JavaPairDStream<String, Integer> wordsCounts = wordsOnes.reduceByKey(new Sum());

		wordsCounts.print();

		wordsCounts.dstream().saveAsTextFiles(outputPathPrefix, "");

		// Start the computation
		jssc.start();

		jssc.awaitTerminationOrTimeout(120000);

		jssc.close();

	}
}
